# SessionUpResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**session_id** | **str** |  | 
**cluster_name** | **str** |  | 
**private_key** | **str** |  | 
**cluster_config** | [**object**](.md) |  | 
**is_same_cluster_config** | **bool** | Deprecated. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


